@@ -1,4 +1,4 @@
-#' Visual Predictive Check (VPC) based on Perl-speaks-NONMEM (PsN) generated VPC files
+#' Visual Predictive Check (VPC) based on Perl-speaks-NONMEM (PsN) generated VPC files (lattice version).
 #' @description
 #' This function creates VPC using output files from the vpc command in Pearl Speaks NONMEM (PsN).
 #' Graphs are generated using the lattice package with many arguments for plot settings are passed
@@ -43,8 +43,8 @@
 #' alpha of CI regions (low, median and high) for model, passed to xyplot, default=c(0.5,0.5,0.5)
 #' @param type
 #' type of VPC plot, 1=display model regions only, 2=as 1 + lines (low, median and high) of data,
-#' 3= as 2 + points for data
-#' type=0 can also be used and then no grapg is produced but instead a list with 2 dataframes is returned.
+#' 3= as 2 + points for data.
+#' type=0 can also be used and then no graph is produced but instead a list with 2 dataframes is returned.
 #' one for the vpcresult and on for the observed data in the vpctab file.
 #' @param ...
 #' Further arguments, passed to xyplot, e.g xlim and ylim axis limits, main for title of plot, abline for adding reference lines, or
@@ -74,10 +74,10 @@
 #' can then be set by using the xyplot argument scales.
 #'
 #'
+#'
 #' @export
 #' @importFrom lattice panel.polygon
 #' @importFrom latticeExtra as.layer
-#' @importFrom xpose4 read.npc.vpc.results
 #' @examples
 #'
 #' # Get path to the example files included in nonmem2R package
@@ -143,7 +143,10 @@ vpcfig<-function(vpcdir=NULL,
 
   dd1<-read.table(file=vpctab,sep=",",header=T)
   dd1$id<-as.numeric(factor(dd1$ID))
-  dd2<-read.npc.vpc.results(vpc.results = vpcresult)
+
+  #dd2<-read.npc.vpc.results(vpc.results = vpcresult) # Expose func
+  dd2<-readVpc(vpc.results = vpcresult)              # Alt1
+  #dd2<-loadVPC(vpcresult)                             # Alt2
 
   ## Change names for DV and TIME in the raw data dataframe dd1
   ii<-match(c(dd2$dv.var,dd2$idv.var),colnames(dd1))
